function ExportHeader: string;
var
  language: string;
begin
  begin
    if copy(GetCurrentLanguage, 1, 2) = 'cs' then language := 'Czech'
    else language := 'English';
  end
 
  Result := 'var cachecode = "' + '' + '";' + CRLF   // remember starting coords across sessions
    + 'var macro_name = "HTML_Custom_MapyCZ.gsk";' + CRLF
    + 'var macro_version = "2.60";' + CRLF
    + 'var SplitScreen = true;' + CRLF
    + 'var OpenInBrowser = true;' + CRLF
    + 'var AllInFilter = true;' + CRLF
    + 'var PrivateVersion = false;' + CRLF
    + 'var testing = false;' + CRLF
    + 'var cur_date = "6.2.2013";' + CRLF
    + 'var language = "' + language + '";' + CRLF
    + 'var notGSAK = true;' + CRLF
    + 'wp = {' + CRLF
end;

function escapeJS(value: string): string;
begin
  Result := RegexReplace('(["\\])', value, '\\$1', True);
  Result := RegexReplace('(\xE2\x80\xA8|\r\n|\r|\n)', Result, '\r\n', False);  
end;

function ExportPoint: string;
  var i: integer;
  var Status, Status2, CacheType, ChildCode: String;
begin
  // get CacheType
  begin
    if GC.CacheType = 'Traditional Cache' then CacheType := 'T'
    else if GC.CacheType = 'Multi-cache' then CacheType := 'M'
    else if GC.CacheType = 'Unknown Cache' then CacheType := 'U'
    else if GC.CacheType = 'Letterbox Hybrid' then CacheType := 'B'
    else if GC.CacheType = 'Earthcache' then CacheType := 'R'
    else if GC.CacheType = 'Wherigo Cache' then CacheType := 'I'
    else if IsValidWM(GC.ID) then CacheType := 'Y'
    else if GC.CacheType = 'Webcam Cache' then CacheType := 'W'
    else if GC.CacheType = 'Virtual Cache' then CacheType := 'V'
    else if GC.CacheType = 'Event Cache' then CacheType := 'E'
    else if GC.CacheType = 'Mega-Event Cache' then CacheType := 'Z'
    else if GC.CacheType = 'Cache In Trash Out Event' then CacheType := 'C'
    else if GC.CacheType = 'Locationless (Reverse) Cache' then CacheType := 'L'
    else if GC.CacheType = 'Lost and Found Event Cache' then CacheType := 'F'
    else if GC.CacheType = 'Project Ape Cache' then CacheType := 'A'    
    else if GC.CacheType = 'GPS Adventures Exhibit' then CacheType := 'X'

    // probably not supported
    else if GC.CacheType = 'Other' then CacheType := 'O'
    else if GC.CacheType = 'BenchMark Cache' then CacheType := 'G'
    else if GC.CacheType = 'Groundspeak HQ Cache' then CacheType := 'H'
    else if GC.CacheType = 'Lost and Found Celebration Cache' then CacheType := 'D'
    else if GC.CacheType = 'Block Party Cache' then CacheType := 'P'
    else CacheType := 'O';
  end
  
  // get Status
  begin
    if GC.CacheStatus = 1 then Status := 'T'
    else if GC.CacheStatus = 2 then Status := 'X'
    else Status := 'A';
  end
  
  // get Status2
  begin
    if GC.IsOwner then Status2 := 'O'
    else if GC.IsFound then Status2 := 'F'
    else Status2 := Status;
  end
    
  // get parent
  if GC.IsListed then
  begin
    Result := '"' + escapeJS(GC.ID) + '": {'
      + 'Name: "' + escapeJS(GC.Name) + '", '
      + 'ShortDescription: "' + escapeJS(GC.ShortDescription) + '", '
      + 'LongDescription: "' + escapeJS(GC.LongDescription) + '", '
      + 'Url: "' + escapeJS('http://coord.info/' + GC.ID) + '", ' 
      + 'CacheType: "' + CacheType + '", '
      + 'CacheTypeWM: "' + escapeJS(GC.CacheType) + '", ' // WM category 
      + 'Latitude: "' + GC.Lat + '", '
      + 'Longitude: "' + GC.Lon + '", '
      + 'HasCorrected: 0, '
      + 'CoordsFormatted: "' + '' + '", ' // created within JS
      + 'Terrain: "' + GC.Terrain + '", '
      + 'Difficulty: "' + GC.Difficulty + '", '
      + 'Container: "' + GC.Size + '", '
      + 'UserFlag: 0, ' // not supported
      + 'Status: "' + Status + '", ' 
      + 'Status2: "' + Status2 + '", ' 
      + 'OwnerName: "' + escapeJS(GC.Author) + '", '
      + 'PlacedDate: "' + formatdatetime('dd"."mm"."yyyy', GC.Hidden) + '"'
      + '},' + CRLF;

      // get children
      for i := 0 to GC.Waypoints.Count - 1 do
      begin
      
        // get Child Code
        begin
          if IsValidGC(GC.ID) then ChildCode := GC.Waypoints[i].PrefixID + copy(GC.ID, 3, 100)
          else ChildCode := GC.Waypoints[i].PrefixID + GC.ID;
        end
      
        Result := Result + '"' + escapeJS(ChildCode) + '": {'
          + 'Parent: "' + escapeJS(GC.ID) + '", '
          + 'Name: "' + escapeJS(GC.Waypoints[i].Name) + '", '          
          + 'Comment: "' + escapeJS(GC.Waypoints[i].Description) + '", '
          + 'Url: "' + escapeJS('http://coord.info/' + GC.ID) + '", ' 
          + 'CacheType: "' + RegexReplace(' ', GC.Waypoints[i].WptType, '', False) + '", ' 
          + 'Latitude: "' + GC.Waypoints[i].Lat + '", '
          + 'Longitude: "' + GC.Waypoints[i].Lon + '", '
          + 'UserFlag: 0, ' // not supported
          + 'CoordsFormatted: "' + '' + '"' // created within JS
          + '},' + CRLF;      
      end;
  end;
end;
 
function ExportFooter: string;
begin
  result := 'dummy:""};';
end;

//************************
 
function ExportAfter(value: string): string;
begin
  StringToFile(FileToString(value), GEOGET_SCRIPTDIR + '\Keskomapa\GeoGet\vars.js');
  BrowseURL(GEOGET_SCRIPTDIR + '\Keskomapa\GeoGet\SplitScreen.htm');
end;

function ExportExtension: string;
begin
  result := '';
end;

function ExportDescription: string;
begin
  if copy(GetCurrentLanguage, 1, 2) = 'cs' then Result := 'Probh generovn promnnch pro mapu...'
  else Result := 'Generating variables for the map...';    
end;

function ExportHint: string;
begin
  if copy(GetCurrentLanguage, 1, 2) = 'cs' then Result := 'Mapa keek.'
  else Result := 'Creates map of caches.';    
end;




