// from: http://www.ifadey.com/2011/07/context-menu-using-raw-javascript/

//********************************************
// context menu functions
//********************************************

var contextMenu =
{
  init: window.setTimeout(function()
  {
    EventUtil.addHandler(document.documentElement, 'click', function click(e, target)
    {
      contextMenu.hideAllContextMenus();
      window.contextMenuActive = false;    
    });
  }, 0),

  hideAllContextMenus: function()
  {
    for (var i in contextMenu.menuList)
      contextMenu.menuList[i].menu.style.display = "none";
  },
  
  addContextMenu: function(element, menu, rightClickCustomFunction, leftClickCustomFunction, options)
  {
    // if context menu is already attached to the element, then exit
    for (var i in contextMenu.menuList)
    {
      if (contextMenu.menuList[i].element === element)
        return 0;
    }    

    options = options || {};
    options.menuIndex = ++contextMenu.menuSettings.max;

    var handlerRightClick = EventUtil.addHandler(element, 'contextmenu', function (e, target)
    {
      if (e.shiftKey || e.ctrlKey || e.altKey)
        return;
    
      EventUtil.preventDefault(e);
      EventUtil.stopPropagation(e);
      contextMenu.hideAllContextMenus();
      menu.style.display = "block";
    
      // are there any pixels outside of the viewport?
      // http://www.quirksmode.org/mobile/viewports.html
      var offset_right  = document.documentElement.clientWidth - (e.clientX + menu.offsetWidth);
      var offset_bottom = document.documentElement.clientHeight - (e.clientY + menu.offsetHeight);
      
      // position menu on the screen so that no part is hidden (if it is too right/low)
      menu.style.top = Math.max(0, (e.clientY - ((offset_bottom < 0) ? menu.offsetHeight : 0))) + "px";
      menu.style.left = Math.max(0, (e.clientX - ((offset_right < 0) ? menu.offsetWidth : 0))) + "px";

      // save last clicked menu index
      contextMenu.menuSettings.last = options.menuIndex;
      
      // save global variable (so that we can test whether any menu is active)
      window.contextMenuActive = true;

      // run custom function
      rightClickCustomFunction(e, target, menu, options);
    });

    var handlerLeftClick = EventUtil.addHandler(menu, 'click', function (e, target)
    {
      // if there are more listeners attached to one menu, choose the correct one
      if (options.menuIndex != contextMenu.menuSettings.last)
        return;
      
      // IE7 treats comments as tags, so switch to parent  
      if (target.tagName === "!")
        target = target.parentNode;
        
      // if returned false or nothing, then hide the menu
      if (!leftClickCustomFunction(e, target, menu, options))
        menu.style.display = 'none';
      else
        EventUtil.stopPropagation(e);
    });
    
    contextMenu.menuList[contextMenu.menuSettings.max] = {handlerRightClick: handlerRightClick, handlerLeftClick: handlerLeftClick, menu: menu, element: element, options: options};
    return contextMenu.menuSettings.max;
  },
  
  removeContextMenu: function(index)
  {
    if (!index || typeof contextMenu.menuList[index] === 'undefined')
      return;

    EventUtil.removeHandler(contextMenu.menuList[index].handlerRightClick);
    EventUtil.removeHandler(contextMenu.menuList[index].handlerLeftClick);
    delete contextMenu.menuList[index];
  },
  
  // max: last added menu index, last: last activated menu index
  menuList: {},
  menuSettings: {max: 0, last: 0}
}

//********************************************
// map context menu
//********************************************

contextMenu.addContextMenu(mapAreaDiv, document.getElementById('contextMenu'), 
function (e, target, menu, options)
{
  // remove keypress propagation
  var menu = document.getElementById('contextMenu');
  EventUtil.addHandler(menu, "keydown", function(e) {EventUtil.stopPropagation(e);});
  EventUtil.addHandler(menu, "keyup", function(e) {EventUtil.stopPropagation(e);});
  EventUtil.addHandler(menu, "keypress", function(e) {EventUtil.stopPropagation(e);});
  
  menu.lastCoords = new SMap.Coords.fromEvent(e, m); 
},

function (e, target, menu, options) 
{
  // retrieve lat/lon
  var coords = menu.lastCoords;       
  var latlon = coords.toWGS84("LatLon");
  var lat = latlon[0];
  var lon = latlon[1];

  if (target.id == "cm_zoom_here")
  ;
        
  else if (target.id == "cm_center_map_here")
    m.setCenter(coords);
  
  else if (target.id == "cm_show_all")
    m.setCenterZoom.apply(m, m.computeCenterZoom(souradnice));

  else if (target.id == "cm_add_child_here")
    window.location.href = "gsak://%FF/Addchild/" + lat + "/" + lon + "/" + cachecode;

  else if (target.id == "cm_add_waypoint_here")
    window.location.href = "gsak://%FF/AddWpt/" + lat + "/" + lon;
     
  else if (target.id == "cm_coordinates_to_clipboard")
    window.location.href = "gsak://%FF/ClipBoard/" + lat + " " + lon;

  else if (target.id == "cm_set_gsak_center_point")
    window.location.href = "gsak://%FF/Center/" + lat + "/" + lon;

  else if (target.id == "cm_run_map_macro")
    window.location.href = "gsak://%FF/MapMacro/" + lat + "/" + lon;

  else if (target.id == "cm_land_registry")
  {
    function openLandRegistry()
    {
      var sjtsk_coords = wgs84_to_sjtsk(lat, lon);
      window.open('http://nahlizenidokn.cuzk.cz/MapaIdentifikace.aspx?&x=' + Math.round(-sjtsk_coords[1]) + '&y=' + Math.round(-sjtsk_coords[0]));
    }
    
    if (!window.coordinatesSJTSKLoaded)
      loadJS(basePath + "coordinates_sjtsk.js", openLandRegistry);
    else
      openLandRegistry();
  }
  
  else if (target.id == "cm_street_view")
  {
    if (typeof StreetViewDiv === 'undefined')
    {
      window.startStreetViewCoords = coords;
      loadCSS(basePath + "streetview.css");
      loadJS(basePath + "streetview.js");
    }
    else
    {
      LoadStreetView(coords);
    }
  }  
  
  else if (target.id == "cm_find_form" || EventUtil.isSubnode(target, document.getElementById("cm_find_form")))
  {
    var form = document.getElementById("findForm");

    // function, that executes online search
    window.findExecute = function ()
    {
      var place = form.elements["findBox"].value;
      
      if (place)
        LocationLookup(place, lat, lon);
    }

    // initialize listeners
    if (!form.getAttribute("initialized"))
    {
      form.setAttribute("initialized", true);

      // prevent automatic submit (handle ENTER manually instead - automatic submit doesn't work in IE)
      EventUtil.addHandler(form, 'submit', function (e, target)
      {
        EventUtil.preventDefault(e);
      });

      // on ENTER execute search
      EventUtil.addHandler(form.elements["findBox"], 'keydown', function (e, target)
      {
        if (e.keyCode == 13)
        {
          window.findExecute();
          EventUtil.preventDefault(e);
          menu.style.display = "none";
        }
      });
    }

    // execute search on clicking label, return (without closing menu) otherwise
    if (target.tagName.toLowerCase() == "span")
      window.findExecute();
    else
      return true;
  }
  
  else if (target.id == "cm_help")
    ui("copybox", {text: tr("about_box"), width: 600, height: 300});
    //alert(tr("about_box"));
});  

//********************************************
// marker context menu
//********************************************

function markerContextMenu(element, code, parent){
  var handlerContextMenu = contextMenu.addContextMenu(element, document.getElementById('contextMenuWP'), 
  function (e, target, menu, options)
  {
    var Code = options.code;
    var parent = options.parent;
    
    // show "Save New Coordinates" only if the point has been dragged + when it's not CC
    document.querySelector("#cmwp_save_new_coordinates").style.display = (wp[Code].dragged && wp[Code].CacheType != "Corrected") ? "block" : "none";
    
    // show/hide add/remove flags items
    document.querySelector("#cmwp_flag_parent").style.display = (!wp[parent].UserFlag) ? "block" : "none";
    document.querySelector("#cmwp_remove_flag_parent").style.display = (wp[parent].UserFlag) ? "block" : "none";
    document.querySelector("#cmwp_flag_child").style.display = (Code !== parent && !wp[Code].UserFlag && wp[Code].CacheType != "Corrected") ? "block" : "none";
    document.querySelector("#cmwp_remove_flag_child").style.display = (Code !== parent && wp[Code].UserFlag && wp[Code].CacheType != "Corrected") ? "block" : "none";
  
    // flag first item (for CSS round borders)
    var first = document.querySelector("#contextMenuWP .cm_first");
    first && remove_class(first, "cm_first");
    
    for (var i = 0, len = menu.childNodes.length; i < len; i++)
    {
      if (menu.childNodes[i].style && menu.childNodes[i].style.display != "none")
      {
        add_class(menu.childNodes[i], "cm_first");
        break;
      }
    }
  
    // show/hide delete child item
    document.querySelector("#cmwp_delete_child").style.display = (Code !== parent && wp[Code].CacheType != "Corrected") ? "block" : "none";
  },
  
  function (e, target, menu, options)
  {
    var Code = options.code;
    var parent = options.parent;

    var lat = wp[Code].Latitude;
    var lon = wp[Code].Longitude;
    
    if (target.id == "cmwp_save_new_coordinates")
    {
      if (confirm(tr("wp_drag_ask")))
      {
        var new_lat = wp[Code].dragged[0];
        var new_lon = wp[Code].dragged[1];
        window.location.href = "gsak://%FF/macro:silent/HTML_Custom_MapyCZ\\Update_Database.gsk?" + "move_marker" + "###" + Code + "###" + + new_lat + "###" + new_lon + "/" + parent;
        
        wp[Code].Latitude = new_lat;
        wp[Code].Longitude = new_lon;
        delete wp[Code].dragged;
      }
    }
    
    else if (target.id == "cmwp_flag_parent")
    {
      window.location.href = "gsak://%FF/flagset:silent/" + parent;
      wp[Code].UserFlag = 1; 
    }
    
    else if (target.id == "cmwp_remove_flag_parent")
    {
      window.location.href = "gsak://%FF/flagclear:silent/" + parent;
      wp[Code].UserFlag = 0; 
    }
    
    else if (target.id == "cmwp_flag_child")
    {
      window.location.href = "gsak://%FF/macro:silent/HTML_Custom_MapyCZ\\Update_Database.gsk?" + "flag_child" + "###" + Code + "/" + parent;
      wp[Code].UserFlag = 1; 
    }
    
    else if (target.id == "cmwp_remove_flag_child")
    {
      window.location.href = "gsak://%FF/macro:silent/HTML_Custom_MapyCZ\\Update_Database.gsk?" + "remove_flag_child" + "###" + Code + "/" + parent;
      wp[Code].UserFlag = 0; 
    }

    else if (target.id == "cmwp_delete_parent")
    {
      if (confirm(tr("wp_delete_parent")))
      {
        window.location.href = "gsak://%FF/macro:silent/HTML_Custom_MapyCZ\\Update_Database.gsk?" + "delete_parent" + "###" + parent + "/" + parent;
        delete_waypoint(get_all_in_family(Code));
      }
    }
    
    else if (target.id == "cmwp_delete_child")
    {
      if (confirm(tr("wp_delete_child")))
      {
        window.location.href = "gsak://%FF/macro:silent/HTML_Custom_MapyCZ\\Update_Database.gsk?" + "delete_child" + "###" + Code + "/" + parent;
        delete_waypoint(Code);
      }
    }
    
    else if (target.id == "cmwp_remove_from_map")
    {
      delete_waypoint((Code == parent || wp[Code].CacheType == "Corrected") ? get_all_in_family(parent) : Code);
    }
  
    // delete all listeners to current menu
    for (var i in contextMenu.menuList)
    {
      if (contextMenu.menuList[i].menu === menu)
        contextMenu.removeContextMenu(i);
    }
  },
  
  {code: code, parent: parent}
  );

  return handlerContextMenu;  
};

window.contextMenuJSLoaded = true;
