function load_coordinates_box()
{
  window.coordinates_box = null;
  
  function createCoordinatesBox()
  {
    // create coordinates box if not already present
    if (!coordinates_box)
    {
      var noprint_div = document.querySelector(".noprint");
      coordinates_box = document.createElement("div");
      coordinates_box.className = "coordinates-box";
      coordinates_box.style.display = "none";
      noprint_div.insertBefore(coordinates_box, noprint_div.firstChild);
      
      // put Seznam logo to bottom (interferes with our box)
      var logo = document.querySelector('#mapadiv div.noprint > img[src*="logo.png"]');
      noprint_div.insertBefore(logo, coordinates_box);

      // on minimap existence/resize/end, change right offset, so it fits
      function minimapHandler(e)
      {
        coordinates_box.style.right = ((e.type == "minimap-end") ? 0 : e.target.offsetWidth) + "px";
      }

      if (window.minimap)
        minimapHandler({target: window.minimap._dom.container});      
      
      m.getSignals().addListener(window, "minimap-resize", minimapHandler);
      m.getSignals().addListener(window, "minimap-end", minimapHandler);

      // update coordinates on mouse move
      JAK.Events.addListener(mapadiv, "mousemove", this, function(e, elm)
      {
        var point = SMap.Pixel.fromEvent(e, m).toCoords(m).toWGS84("LatLon");
        var lat = point[0];
        var lon = point[1];
        
        // get degrees
        var lat_deg = lat.toFixed(7);
        var lon_deg = lon.toFixed(7);
        
        // get minutes
        var lat_min = ((lat > 0) ? "N" : "S") + " " + getDegrees(lat) + "° " + getMinutes(lat).toFixed(3);
        var lon_min = ((lon > 0) ? "E" : "W") + " " + getDegrees(lon) + "° " + getMinutes(lon).toFixed(3); 

        // get seconds
        var lat_sec = ((lat > 0) ? "N" : "S") + " " + getDegrees(lat) + "° " + Math.floor(getMinutes(lat)) + "' " + getSeconds(lat).toFixed(2) + "\"";
        var lon_sec = ((lon > 0) ? "E" : "W") + " " + getDegrees(lon) + "° " + Math.floor(getMinutes(lon)) + "' " + getSeconds(lon).toFixed(2) + "\""; 

        // get UTM
        var utm = LatLonToUTMXY(lat, lon);
        var zone_utm = utm[2] + "U";
        var lon_utm = ((lon > 0) ? "E" : "W") + " " + utm[0].toFixed(0);
        var lat_utm = ((lat > 0) ? "N" : "S") + " " + utm[1].toFixed(0);
 
        // get S-JTSK
        var sjtsk = wgs84_to_sjtsk(lat, lon);
        var lat_sjtsk = "X " + sjtsk[0].toFixed(3);
        var lon_sjtsk = "Y " + sjtsk[1].toFixed(3);
        
        // get elev
        var elv = window.elevCallbackObj = window.elevCallbackObj || {};
        elv.lat = lat;
        elv.lon = lon;
        elv.request = true;
        
        if (typeof elv.oldLat === 'undefined')
        {
          // run on first update (+ delay it, so it runs when coordinate box is visible)
          window.setTimeout(elevInterval, 100);
          elv.oldLat = "";
        }

        // write data to div
        var str = "";
        str += "<span id='coords_deg'><span class='coords_box_label'>" + tr("Degrees") + ":</span>  " + lat_deg + "  " + lon_deg + "</span>";
        str += "<span id='coords_min'><span class='coords_box_label'>" + tr("Minutes") + ":</span>  " + lat_min + "  " + lon_min + "</span>";
        str += "<span id='coords_sec'><span class='coords_box_label'>" + tr("Seconds") + ":</span>  " + lat_sec + "  " + lon_sec + "</span>";
        str += "<span id='coords_utm'><span class='coords_box_label'>" + tr("UTM") + ":</span>  " + zone_utm + "  " + lon_utm + "  " + lat_utm + "</span>";
        str += "<span id='coords_sjtsk'><span class='coords_box_label'>" + tr("S-JTSK") + ":</span>  " + lat_sjtsk + "  " + lon_sjtsk + "</span>";
        str += "<span id='coords_elv'><span class='coords_box_label'>" + tr("Elevation") + ":</span>  <span id='callback_elev'>" + (elv.elevation || "???") + "</span> m</span>";
        str += "<span id='coords_help'>" + tr("_coords_box_help") + "</span>";
        
        coordinates_box.innerHTML = str;
        coordinates_box.style.display = "";
      });

      // elevation request function - limit it per time, so we don't overuse the server
      function elevInterval()
      {
        // problem: low value makes key event sometimes fail in IE
        window.setTimeout(elevInterval, 1000);

        // get request object
        var elv = window.elevCallbackObj;

        // return if no request available or 
        if (!elv || coordinates_box.style.display == "none" || coordinates_box.style.visibility == "hidden"
          || (elv.lat === elv.oldLat && elv.lon === elv.oldLon))
          return;

        window.callbackElevation = function(result)
        {
          elevation = result.elevationProfile[0].height;

          if (elevation == -32768)
            elevation = "???";
          
          // save elevation to div  
          var elevElm = document.getElementById("callback_elev");
          
          if (elevElm)
            elevElm.innerHTML = elevation;
            
          elv.elevation = elevation;
          // log(elevation);
        }
        
        // http://open.mapquestapi.com/elevation/
        if (elv.request)
          loadJS("http://open.mapquestapi.com/elevation/v1/profile?callback=callbackElevation&shapeFormat=raw&latLngCollection=" + elv.lat + "," + elv.lon);

        elv.request = false;
        elv.oldLat = elv.lat;
        elv.oldLon = elv.lon;
      };

      // make function copyCoordinates available everywhere
      window.copyCoordinates = copyCoordinates;
      
      // prevent CTRL+C from bubbling
      EventUtil.addHandler(coordinates_box, "keydown", function(e) {EventUtil.stopPropagation(e);});
      EventUtil.addHandler(coordinates_box, "keyup", function(e) {EventUtil.stopPropagation(e);});
      EventUtil.addHandler(coordinates_box, "keypress", function(e) {EventUtil.stopPropagation(e);});    
    }
  }
  
  function copyCoordinates()
  {
    if (coordinates_box.style.display == "none" || coordinates_box.style.visibility == "hidden")
      return;
    
    // extract text  
    var text = "";
    var fields = ["coords_deg", "coords_min", "coords_sec", "coords_utm", "coords_sjtsk", "coords_elv"];
    
    while (fields.length)
      text += document.getElementById(fields.shift()).innerHTML.replace(/<.*?>/g, "") + (fields.length ? "\n" : "");

    // display copybox
    ui("copybox", {text: text, width: 380, height: 100});
  }

  function getDegrees(c)  /* number is cut off */
  {
    return (Math.floor(Math.abs(c)));
  }

  function getMinutes(c)
  {
    return ((Math.abs(c) - getDegrees(c)) * 60);
  }
  
  function getSeconds(c)
  {
    return ((getMinutes(c) - Math.floor(getMinutes(c))) * 60);
  }
  
  //#################################################x
  if (!window.coordinatesSJTSKLoaded)
    loadJS(basePath + "coordinates_sjtsk.js");

  if (!window.coordinatesUTMLoaded)
    loadJS(basePath + "coordinates_utm.js");      
    
  var interval = window.setInterval(function()
  {
    if (window.coordinatesSJTSKLoaded && window.coordinatesUTMLoaded)
    {
      window.clearInterval(interval);
      createCoordinatesBox();
    }
  }, 0);  
    
}






