// functions for S-JTSK <-> WGS84 conversion (needed for katastr)
function wgs84_to_sjtsk(lat, lon)
{               
  var FI1_rad = lat * Math.PI/180;
  var LA1_rad = lon * Math.PI/180;
  
  var a1 = 6378137;
  var f1 = 0.00335292371299641;
  var a2 = 6377397.155;
  var f2 = 0.00334277318217481;
  var dX = -589;
  var dY = -76;
  var dZ = -480;
  var e1 = Math.sqrt(2 * f1 - f1 * f1);
  var M = a1 * (1 - e1 * e1) / Math.pow((1 - e1 * e1 * Math.sin(FI1_rad) * Math.sin(FI1_rad)),1.5);
  var N = a1 / Math.sqrt(1 - e1 * e1 * Math.sin(FI1_rad) * Math.sin(FI1_rad));
  var dFI_sec = (-dX * Math.sin(FI1_rad) * Math.cos(LA1_rad) - dY * Math.sin(FI1_rad) * Math.sin(LA1_rad) + dZ * Math.cos(FI1_rad) + (a1 * (f2 - f1) + f1 * (a2 - a1)) * Math.sin(2 * FI1_rad)) / (M * Math.sin(Math.PI / 180 / 3600));
  var FI2 = (-dX * Math.sin(LA1_rad) + dY * Math.cos(LA1_rad)) / (N * Math.cos(FI1_rad) * Math.sin(Math.PI / 180 / 3600));
  lat = parseFloat(lat) + dFI_sec / 3600;
  lon = parseFloat(lon) + FI2 / 3600;

  var FI = lat;
  var LA_Gr = lon;
  var LA = LA_Gr + (17 + 40 / 60 + 0 / 3600);
  var FI_rad = FI * Math.PI / 180;
  var LA_rad = LA * Math.PI / 180;
  var a	= 6377397.155;
  var b	= 6356078.96325;
  var e1 = Math.sqrt((a * a - b * b) / (a * a));
  var e2 = Math.sqrt((a * a - b * b) / (b * b));
  var fi0 = 59 + 42 / 60 + 42.69689 / 3600;
  var la0 = 42 + 31 / 60 + 31.41725 / 3600;
  var fi0_rad = fi0 * Math.PI / 180;
  var la0_rad = la0 * Math.PI / 180;
  var ro0	= 1298039.0046;
  var FIn = 49.5;
  var FIn_rad = FIn * Math.PI / 180;
  var Vn = Math.sqrt(1 + e2 * e2 * Math.cos(FIn_rad) * Math.cos(FIn_rad));
  var fi_n = Math.atan2(Math.tan(FIn_rad), Vn);
  var n = Math.sin(FIn_rad) / Math.sin(fi_n);
  var k = (Math.tan(Math.PI / 4 + fi_n / 2)) / (Math.pow(Math.tan(Math.PI / 4 + FIn_rad / 2), n) * Math.pow(((1 - e1 * Math.sin(FIn_rad)) / (1 + e1 * Math.sin(FIn_rad))), (n * e1 / 2)));
  var tga = Math.atan(k * Math.pow(Math.tan(Math.PI / 4 + FI_rad / 2), n) * Math.pow(((1 - e1 * Math.sin(FI_rad)) / (1 + e1 * Math.sin(FI_rad))), n * e1 / 2));
  var fi = (tga - Math.PI / 4) * 2;
  var la = la0_rad - n * LA_rad;
  var betav = Math.acos(Math.sin(fi) * Math.sin(fi0_rad) + Math.cos(fi) * Math.cos(fi0_rad) * Math.cos(la));
  var lambv = Math.asin(Math.cos(fi) * Math.sin(la) / Math.sin(betav));
  var betakv = Math.PI * 11.5 / 180;
  var m = Math.cos(betakv);
  var RGauss_scale = 6380065.5402;
  var c = RGauss_scale * Math.sin(betakv) / m / Math.pow(Math.tan(betakv / 2), m);
  var ro1 = c  * Math.pow(Math.tan(betav / 2), m);
  var gamma = m * lambv;
  var x = ro1 * Math.cos(gamma);
  var y = ro1 * Math.sin(gamma);

  return [x, y];
}

function sjtsk_to_wgs84(x, y)
{
  var fi0 = 59 + 42 / 60 + 42.69689 / 3600;
  var la0 = 42 + 31 / 60 + 31.41725 / 3600;
  var fi0_rad = fi0 * Math.PI / 180;
  var la0 = la0 * Math.PI / 180;
  var betakv = Math.PI * 11.5 / 180;
  var m = Math.cos(betakv);
  var gamma = Math.atan2(y, x);
  var lambv = gamma / m;
  var ro1 = Math.sqrt(x * x + y * y);
  var RGauss_scale = 6380065.5402;
  var c = RGauss_scale * Math.sin(betakv) / m / Math.pow(Math.tan(betakv / 2), m);
  var betav = 2 * Math.atan(Math.pow(ro1 / c, 1 / m));
  var fi = Math.asin(Math.cos(betav) * Math.sin(fi0_rad) - Math.sin(betav) * Math.cos(fi0_rad) * Math.cos(lambv));
  var la = Math.asin(Math.sin(betav) * Math.sin(lambv) / Math.cos(fi));
  var a	= 6377397.155;
  var b	= 6356078.96325;
  var e1 = Math.sqrt((a * a - b * b) / (a * a));
  var e2 = Math.sqrt((a * a - b * b) / (b * b));
  var FIn_rad = Math.PI * 49.5 / 180;
  var Vn = Math.sqrt(1 + e2 * e2 * Math.cos(FIn_rad) * Math.cos(FIn_rad));
  var fi_n = Math.atan2(Math.tan(FIn_rad), Vn);
  var n = Math.sin(FIn_rad) / Math.sin(fi_n);
  var k = Math.tan(Math.PI / 4 + fi_n / 2) / (Math.pow(Math.tan(Math.PI / 4 + FIn_rad / 2), n) * Math.pow((1 - e1 * Math.sin(FIn_rad)) / (1 + e1 * Math.sin(FIn_rad)), n * e1 / 2));
  var LA_rad = (la0 - la) / n;
  var FIk = 2 * Math.atan(Math.pow(1 / k * Math.tan(Math.PI / 4 + fi / 2), 1 / n)) - Math.PI / 2;
  var tga = Math.pow((1 - e1 * Math.sin(FIk)) / (1 + e1 * Math.sin(FIk)), n * e1 / 2);
  var FI1_rad = 2 * Math.atan(Math.pow(1 / k / tga * Math.tan(Math.PI / 4 + fi / 2), 1 / n)) - Math.PI / 2;
  var tga2 = Math.pow((1 - e1 * Math.sin(FI1_rad)) / (1 + e1 * Math.sin(FI1_rad)), n * e1 / 2);
  var FI2_rad = 2 * Math.atan(Math.pow(1 / k / tga2 * Math.tan(Math.PI / 4 + fi / 2), 1 / n)) - Math.PI / 2;
  var tga3 = Math.pow((1 - e1 * Math.sin(FI2_rad)) / (1 + e1 * Math.sin(FI2_rad)), n * e1 / 2);
  var FI3_rad = 2 * Math.atan(Math.pow(1 / k / tga3 * Math.tan(Math.PI / 4 + fi / 2), 1 / n)) - Math.PI / 2;
  var tga4 = Math.pow((1 - e1 * Math.sin(FI3_rad)) / (1 + e1 * Math.sin(FI3_rad)), n * e1 / 2);
  var FI4_rad = 2 * Math.atan(Math.pow(1 / k / tga4 * Math.tan(Math.PI / 4 + fi / 2), 1 / n)) - Math.PI / 2;
  var tga5 = Math.pow((1 - e1 * Math.sin(FI4_rad)) / (1 + e1 * Math.sin(FI4_rad)), n * e1 / 2);
  var FI_rad = 2 * Math.atan(Math.pow(1 / k / tga5 * Math.tan(Math.PI / 4 + fi / 2), 1 / n)) - Math.PI / 2;
  var FI = FI_rad * 180 / Math.PI;
  var LA_Ferro = LA_rad * 180 / Math.PI;
  var LA_Greenw = LA_Ferro - (17 + 40 / 60 + 0 / 3600);
  var FI1 = FI;
  var LA1 = LA_Greenw;

  var FI1_rad = FI1 * Math.PI / 180;
  var LA1_rad = LA1 * Math.PI / 180;
  var a1 = 6377397.155;
  var f1 = 0.00334277318217481;
  var a2 = 6378137;
  var f2 = 0.00335281066474748;
  var dX = 589;
  var dY = 76;
  var dZ = 480;
  var e1 = Math.sqrt(2 * f1 - f1 * f1);
  var M = a1 * (1 - e1 * e1) / Math.pow((1 - e1 * e1 * Math.sin(FI1_rad) * Math.sin(FI1_rad)), 1.5);
  var N = a1 / Math.sqrt(1 - e1 * e1 * Math.sin(FI1_rad) * Math.sin(FI1_rad));
  var dFI_sec = (-dX * Math.sin(FI1_rad) * Math.cos(LA1_rad) - dY * Math.sin(FI1_rad) * Math.sin(LA1_rad) + dZ * Math.cos(FI1_rad) + (a1 * (f2 - f1) + f1 * (a2 - a1)) * Math.sin(2 * FI1_rad)) / (M * Math.sin(Math.PI / 180 / 3600));
  var dLA_sec = (-dX * Math.sin(LA1_rad) + dY * Math.cos(LA1_rad)) / (N * Math.cos(FI1_rad) * Math.sin(Math.PI / 180 / 3600));
  var FI2 = FI1 + dFI_sec / 3600;
  var LA2 = LA1 + dLA_sec / 3600;  

  return [FI2, LA2];
}

window.coordinatesSJTSKLoaded = true;  
