  /*
     EventUtil is cross browser event handling object
     source is taken from book "Pro JavaScript for Web Developers, 3rd Edition"
  */ 
  var EventUtil = 
  {
    DOMReady: function(f) 
    {
      if (document.addEventListener) 
        document.addEventListener("DOMContentLoaded", f, false);
      else 
        window.setTimeout(f, 0);
    },
  
    addHandler: function(element, type, handler, capture) 
    {
      // element is null/undefined? return
      if (!element)
        return;    
    
      // encapsulate handler
      var handlerFn = function(e)
      {
        var e = EventUtil.getEvent(e);
        var target = EventUtil.getTarget(e);
        return (handler(e, target));
      };

      // add listener
      if (element.addEventListener) 
        element.addEventListener(type, handlerFn, !!capture);
      else if (element.attachEvent && !capture) 
        element.attachEvent('on' + type, handlerFn);
      else if (!capture) 
        element['on' + type] = handlerFn;
    
      return [element, type, handlerFn, !!capture];
    },
    
    removeHandler: function(element, type, handler, capture)
    {
      if (arguments.length == 1)
          return(EventUtil.removeHandler.apply(this, element));
  
      if (element.removeEventListener)
        element.removeEventListener(type, handler, !!capture);
      else if (element.detachEvent)
        element.detachEvent('on' + type, handler);
      else
        element['on' + type] = null;
    },  
   
    getEvent: function(e) {return e || window.event;},
    getTarget : function(e) {return e.target || e.srcElement;},
    preventDefault: function(e) {e.preventDefault ? e.preventDefault() : e.returnValue = false;},
    stopPropagation: function(e) {e.stopPropagation ? e.stopPropagation() : e.cancelBubble = true;},
    
    // mouseover / mouseout
    getRelatedTarget: function(e){var ret = e.relatedTarget || e.toElement || e.fromElement; return (ret ? ret : null);},
  
    addMouseHandler: function(element, type, handler, capture)
    {
      // info: http://www.quirksmode.org/js/events_mouse.html
      // info: http://blog.stchur.com/2007/03/15/mouseenter-and-mouseleave-events-for-firefox-and-other-non-ie-browsers/
      if (type == "mouseenter" || type == "mouseleave")
      {
        var mouseEnterSupport = (typeof document.documentElement.onmouseleave !== 'undefined');

        if (!mouseEnterSupport)
          type = (type == "mouseenter") ? "mouseover" : "mouseout";

        var handlerFn = function(e)
        {
          var e = EventUtil.getEvent(e);
          var target = EventUtil.getTarget(e);
          
          // mouseover/mouseout - exit if we don't have the right element
          if (!mouseEnterSupport && EventUtil.isSubnode(EventUtil.getRelatedTarget(e), element))
            return;

          return (handler(e, target));
        };
      }
    
      return(EventUtil.addHandler(element, type, handlerFn || handler, capture));
    },   
  
    // keypress    
    getCharCode: function(e) 
    {
      //log(e.key);
      if (e.key)
        return e.key.charCodeAt(0);
          
      return ((typeof e.charCode == "number") ? e.charCode : e.keyCode)
    },
    
    // helpful function
    isSubnode: function(node, parent)
    {
      while (node.parentNode !== null && node !== parent)
        node = node.parentNode;
      
      return (node === parent);
    },
    
    // get wheel delta
    getWheelDelta: function(e)
    {
      if (e.wheelDelta)
        return ((JAK.Browser.client == "opera" && JAK.Browser.version < 9.5) ? -e.wheelDelta : e.wheelDelta);
      else
        return (-e.detail * 40);
    }
  };

  // dynamically load .js file
  function loadJS(url, customFn)
  {
    var head = document.head || document.getElementsByTagName("head")[0] || document.documentElement;
    var script = document.createElement("script");
    script.async = "async";
    script.src = url;
    
    // from jQuery
    var done = false;

    script.onload = script.onreadystatechange = function()
    {
      if (!done && (!this.readyState || /loaded|complete/.test(script.readyState))) 
      {
        done = true;
        customFn && customFn();

        // handle memory leak in IE
        script.onload = script.onreadystatechange = null;
        head && script.parentNode && head.removeChild(script);
      }
    };    

    head.appendChild(script);
  }
  
  // dynamically load .css file
  function loadCSS(url, element)
  {
    var link = document.createElement("link");
    link.rel = "stylesheet";
    link.type = "text/css";
    link.href = url;
    var head = element || document.getElementsByTagName("head")[0];
    head.appendChild(link);
  }

 // detect javascript errors
//   window.onerror=function(msg, url, linenumber)
//   {
//     alert('Error message: '+msg+'\nURL: '+url+'\nLine Number: '+linenumber)
//     return true
//   }
  
  // suppress javascript errors
//   window.onerror = function(){return true;};  

  

  // *** cookie handling ***
  // https://developer.mozilla.org/en-US/docs/DOM/Storage
  function write_cookie(cookiename, value)
  {
    // localStorage (doesn't work locally in IE, necessary for Webkit)
    if (window.localStorage && JAK.Browser.client != "opera")
      localStorage.setItem(cookiename, value);
      
    // cookie
    else
      document.cookie = escape(cookiename) + "=" + escape(value) + "; expires=Tue, 19 Jan 2038 03:14:07 GMT; path=/";
  }
  
  function clear_cookie(cookiename)
  {
    if (window.localStorage)
      localStorage.removeItem(cookiename);
    
    else
      document.cookie = escape(cookiename) + "=; expires=Thu, 01 Jan 1970 00:00:00 GMT; path=/";
  };

  function read_cookie(cookiename)
  {
    // local storage   
    if (window.localStorage && JAK.Browser.client != "opera")
      return(localStorage.getItem(cookiename));
    
    // test if cookie exists
    if ((new RegExp("(?:^|;\\s*)" + escape(cookiename).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=")).test(document.cookie) == false)
      return null;
    
    // get cookie
    var cookie = unescape(document.cookie.replace(new RegExp("(?:^|.*;\\s*)" + escape(cookiename).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=\\s*((?:[^;](?!;))*[^;]?).*"), "$1"));

    return(cookie);
  }

  // logger
  function log(string)
  {
    if (typeof testing !== 'undefined' && testing === false)
      return;
      
    // cross-origin policy for local files:
    // IE: unrestricted (likely - as of IE10)
    // Firefox: same directory or subdirectory (https://developer.mozilla.org/en-US/docs/Same-origin_policy_for_file:_URIs)
    // Chrome: banned (run with flag "--allow-file-access-from-files")
    
    // write to logdiv (accessing top frame only available in IE)
    var logdiv = document.getElementById("idlogger");

    if (!logdiv && navigator.appName == 'Microsoft Internet Explorer')
    {
      try {logdiv = window.top.document.getElementById("idlogger")} catch(ex){};
    }
     
    if (logdiv)
    {
      if (typeof logdiv.insertAdjacentHTML !== 'undefined')
        logdiv.insertAdjacentHTML("afterbegin", string + "<br>")
      else
        logdiv.innerHTML = string + "<br>" + logdiv.innerHTML;
    }
    
    // write to console      
    if (typeof console !== 'undefined' && typeof console.log !== 'undefined')
    {
      try {console.log(string)} catch(ex){};
    }
  }

  // print all object properties/values
  function log_object(obj)
  {
    for (var prop in obj)
    {
      try
      {
        log(prop + ": " + (/*obj.hasOwnProperty(prop)*/1 ? obj[prop] : "N/A"));
      }
      catch(ex)
      {
        log("<span style='color: red'>" + prop + ": reading property failed!</span>");
      }      
    }
  }
  
  // timer
  function timer_start(name)
  {
    if (typeof timers === 'undefined') timers = {};
    timers[name] = new Date().getTime();
  }
  
  function timer_end(name)
  {
    log(name + ": " + (new Date().getTime() - timers[name]) / 1000 + ' s');
  }  

  // *** add/remove/swap classname (used as flags for CSS) ***
  function setClassList()
  {
    class_list = (typeof document.body.classList !== 'undefined');
  }
  
  function get_elements (obj)
  {
    // string --> querySelectorAll, object -> return as is
    return ((typeof obj === 'string') ? document.querySelectorAll(obj) : [obj]);
  }
  
  function contains_class (object, class_name)
  {
    if (!class_name)
      return false;  
  
    if (typeof class_list === 'undefined') setClassList();             
    var elements = get_elements(object);
    var re = new RegExp('\\b' + class_name + '(?!\\w)', '');
    
    for (var i = 0; i < elements.length; i++)
      if (class_list ? (elements[i].classList.contains(class_name)) : (elements[i].className.search(re) != -1)) return true;

    return false;
  }  
  
  function add_class (object, class_name)
  {
    if (!class_name)
      return;
  
    if (typeof class_list === 'undefined') setClassList();           
    var elements = get_elements(object);
      
    for (var i = 0; i < elements.length; i++)
      class_list ? (elements[i].classList.add(class_name)) : (elements[i].className += ' ' + class_name);
  }
  
  function remove_class (object, class_name)
  {
    if (!class_name)
      return;  
  
    if (typeof class_list === 'undefined') setClassList();           
    var elements = get_elements(object);
    var re = new RegExp(' ?\\b' + class_name + '(?!\\w)', 'g');

    for (var i = 0; i < elements.length; i++)
      class_list ? (elements[i].classList.remove(class_name)) : (elements[i].className = elements[i].className.replace(re, ''));
  }
    
  function toggle_class (object, class_name)
  {
    if (!class_name)
      return;  
  
    if (typeof class_list === 'undefined') setClassList();           
    var elements = get_elements(object);
    
    for (var i = 0; i < elements.length; i++)
    {
      if (class_list)
        elements[i].classList.toggle(class_name);
      else
      {  
        if (contains_class(elements[i], class_name))
          remove_class(elements[i], class_name);
        else
          add_class(elements[i], class_name);
      }
    }
  }
  
  // Array Remove - By John Resig (MIT Licensed)
  Array.prototype.remove = function(from, to)
  {
    var rest = this.slice((to || from) + 1 || this.length);
    this.length = from < 0 ? this.length + from : from;
    return this.push.apply(this, rest);
  };
  

  

//alert(navigator.appVersion);

  // fix edit boxes (UTF-8 not working inside of GSAK) 
  if (navigator.appName == 'Microsoft Internet Explorer')
  {
    window.setTimeout(function()
    {
      loadJS("OlderBrowsers/setSelectionRange.js");

      if (typeof fixGSAKKeyPress === 'undefined')
        loadJS((window.basePath || "../Macros/HTML_Custom_MapyCZ/") + "OlderBrowsers/setSelectionRange.js");

      fixGSAKKeyPress(document.documentElement, true);
      
      // fix edit boxes (IE7-8, where capture mode doesn't work)
      if (typeof document.addEventListener === 'undefined')
      {
        fixGSAKKeyPress(document.getElementById("findBox"), false);   /* context menu search form */
        fixGSAKKeyPress(document.getElementById("address"), false);   /* GSAK google maps find box */
      }
    }, 1500);
  }

  function cloneObject(obj)
  {
    return JSON.parse(JSON.stringify(obj));
  }
  
  // load UI custom element
  function ui(fn, options)
  {
    if (!window.UILoaded)
    {
      loadCSS(basePath + "ui.css");
      loadJS(basePath + "ui.js", function(){window[fn](options);});
    }
    else
      window[fn](options);  
  }
  
  // file dialog
  function initFileLoad(fn)
  {
    if (!window.Formats)
      loadJS(basePath + "formats.js");

    if (!window.fileInput)
      loadJS(basePath + "filereader.js");
      
    function check()
    {
      if (window.Formats && window.fileInput)
        fn && fn();
      else
        window.setTimeout(check, 50);
    }

    check();
  }

  function loadFile(elementName, clickedButton)
  {
    initFileLoad(function()
    {
      document.getElementById(elementName || "fileInput").click();
    });
  }
  
  // isArray polyfill
  if(!Array.isArray) 
  {
    Array.isArray = function (vArg) 
    {
      return Object.prototype.toString.call(vArg) === "[object Array]";
    };
  }  
