// encapsulate original function
function encapsulate (object, variable, fn)
{
  object[variable + "Orig"] = object[variable];
  object[variable] = fn;
}

// ************
// function setCenterZoom has no business calling setProjection
// (fixes reseting projection to UTM33 where zoom 19 was set)
// - our method may have issues, so replace the calling function instead
encapsulate(SMap.prototype, "setProjection", function(projection)
{
  if(arguments.callee.caller != this.setCenterZoom)
    this.setProjectionOrig(projection);
  // zoom may not be updated properly after leaving zoom 19, so fix it
  else
    this.redraw();
});

// ************
// get current layer + automatically switch projection + let us know before turning on the layer
encapsulate(SMap.Control.Layer.prototype, "_itemClick", function(e, elm)
{
  for (var id in this._layers) 
  {
  	if (this._layers[id] == elm)
    {
      // equalize zoom when switching from projection to projection
      var _old = SMap.CONFIG[this.getMap().CurrentMapId].projection || SMap.projUTM33;
      var _new = SMap.CONFIG[id].projection || SMap.projUTM33;
      
      if (_new !== _old && _old === SMap.projUTM33 && _new === SMap.projMercator)
      {
        //this.getMap().setZoom(this.getMap().getZoom() + 2);
        this.getMap()._zoom += 2;
      }
      else if (_new !== _old && _old === SMap.projMercator && _new === SMap.projUTM33)
      {
        //this.getMap().setZoom(this.getMap().getZoom() - 2);
        this.getMap()._zoom -= 2;
      }

      // set new ID
      this.getMap().CurrentMapId = id;
    }
  }

  this._itemClickOrig(e, elm);
});

encapsulate(SMap.Layer.prototype, "enable", function()
{
  if (SMap.CONFIG[this.getId()] && SMap.CONFIG[this.getId()].preview)
  {
    // no ID set yet? then set it (will be updated in _itemClick)
    this.getMap().CurrentMapId = this.getMap().CurrentMapId || this.getId();
    
    if (this.getId() == this.getMap().CurrentMapId)
    {
      this.getMap().setProjection(SMap.CONFIG[this.getId()].projection || SMap.projUTM33);
      this.getMap().getSignals().makeEvent("layer-change-before", this.getId());
    }
  }
  
  this.enableOrig(this);
});

// ************
// coord fixes - this object contains LatLon->PP results
// (helps fix incorrect UTM->WGS84 conversion outside Europe/Africe)

// this removes mapy.cz original limitation to Europe and North Africa only
encapsulate(SMap.Coords.prototype, "isValid", function()
{
  var c = this.toWGS84();
  
  // latitude: using +-90 results in texture errors on poles (so use lower values)
  // longitude:  can be as high/low as we desire (we get rotating world)
  return (c[1] > -75 && c[1] < 85 && c[0] > -360 && c[0] < 360); 
});

SMap.Coords.prototype.isValidUTM33 = function()
{
  var c = this.toWGS84();
  return (c[1] > 38 && c[1] < 57 && c[0] > 5 && c[0] < 25); 
}

SMap.Coords.prototype.CoordCenter = {};

// fromWGS84 - add result of conversion to CoordCenter object
encapsulate(SMap.Coords, "fromWGS84", function(latD, lonD)
{
  var ret = SMap.Coords.fromWGS84Orig(latD, lonD);

  // save conversion
  SMap.Coords.prototype.CoordCenter[[ret.x, ret.y]] = [parseFloat(latD), parseFloat(lonD)];
  //log("fromWGS84: " + latD + ", " + lonD + " >>> " + ret.x + "_" + ret.y);
  return ret;
});

// toWGS84 - retrieve correct WGS84 coordinates (if possible)
encapsulate(SMap.Coords.prototype, "toWGS84", function(format)
{
  // convert WGS84->PP previously run, so just retrieve result and format it using line from original function
  var XY = SMap.Coords.prototype.CoordCenter[[this.x, this.y]];
  
  if (typeof XY !== 'undefined')
  {
    //log("toWGS84: " + this + " >>> " + result);
   	var ret = (typeof(format) == "number") ? this._formatWGS84(XY, format) : XY;   
  }
  
  // when in UTM33 maps - no previous WGS84->PP conversion, so run default function
  else
  {
    var ret = this.toWGS84Orig(format);
    //log("Fail toWGS84: " + this + " >>> " + ret);
  }
  
  // export as [lat, lon] and fix longitude outside of +-180
  if (format == "LatLon")
  {
    // retrieve lat/lon
    var lat = ret[1];
    var lon = ret[0];
  
    // longitude may go over 180 in both directions, so account for that
    lon = (lon + 360 * Math.ceil(Math.abs(lon) / 360)) % 360;
    lon = (lon >= 180) ? (lon - 360) : lon;

    ret = [lat, lon];  
  }
  
  return ret;
});

// fromUTM33 - just for monitoring when needed
// encapsulate(SMap.Coords, "fromUTM33", function(x, y)
// {
//  var latlon = SMap.Coords.fromUTM33Orig(x, y);
//  //log("fromUTM33: " + x + "_" + y + " >>> " + latlon);
//  return latlon;
// });

// computeCenterZoom: compute center zoom based on projection
encapsulate(SMap.prototype, "computeCenterZoom", function(arr, usePadding)
{
  var projection = SMap.CONFIG[this.getMap().CurrentMapId].projection;
  
  if (projection && projection !== SMap.projUTM33)
  {
   	/* WGS varianta - copied from map.js*/
   	var minX = Infinity;
   	var minY = Infinity;
   	var maxX = -Infinity;
   	var maxY = -Infinity;
   	for (var i=0;i<arr.length;i++) {
   		var item = arr[i].toWGS84();
   		minX = Math.min(minX, item[0]);
   		minY = Math.min(minY, item[1]);
   		maxX = Math.max(maxX, item[0]);
   		maxY = Math.max(maxY, item[1]);
   	}
   	var x = (minX+maxX)/2;
   	var y = (minY+maxY)/2;
   	
   	/* pocet stupnu, ktere chceme zobrazit */
   	var diffX = maxX-minX;
   	var diffY = maxY-minY;
   	
   	/* kolikatinu sveta potrebujeme zobrazit */
   	var w = this._size.x;
   	var h = this._size.y;
   	if (usePadding) { 
   		w -= this._padding.left;
   		w -= this._padding.right;
   		h -= this._padding.top;
   		h -= this._padding.bottom;
   	}
   
   	var fracX = (360*w)/(SMap.Projection.Mercator.WORLD_SIZE * diffX);
   	var fracY = (180*h)/(SMap.Projection.Mercator.WORLD_SIZE * diffY);
   	var frac = Math.min(fracX, fracY);
   
   	var zoom = Math.floor(Math.log(frac) / Math.LN2);
   
   	return [SMap.Coords.fromWGS84(x,y),zoom];
  }
  else
    return(this.computeCenterZoomOrig(arr, usePadding));
});

// ************
// fix local XHR (for oblique layer)
if (JAK.Browser.client == "ie" && document.protocol == "File Protocol")   
{
  // remove layer 19 for IE8-
  // doesn't work also in IE9 when using MOTW
  // (http://msdn.microsoft.com/en-us/library/ms537628(v=vs.85).aspx)
  if (JAK.Browser.version <= 8)
     SMap.CONFIG.obliqueExtents = [];

  // in IE9+, change XDomainRequest to XMLHttpRequest (otherwise calls will be denied)  
  else
    XDomainRequest = XMLHttpRequest;
}

// note: in webkit, marker title can't coexist with draggable markers (displaying card then often fails)
// (fixed by displaying div on hover instead)

// ************
// addDefaultLayer - add custom build url
encapsulate(SMap.prototype, "addDefaultLayer", function(id)
{
  var layer = this.addDefaultLayerOrig(id);
  layer._buildURL = SMap.CONFIG[id].buildUrl || layer._buildURL;  
  return layer;
});

// create default projections (so that we don't have to create them each time we change a map
SMap.projUTM33 = new SMap.Projection.UTM33();
SMap.projMercator = new SMap.Projection.Mercator();

/*** fix listener errors, when we double click on a marker ***/
encapsulate(SMap.prototype, "animate", function(c, options)
{
  if (JAK.Timekeeper.getInstance()._findListener(this) == -1)
    return (this.animateOrig(c, options));
});

encapsulate(SMap.prototype, "setZoom", function(z, fixedPoint, animate)
{
  if (JAK.Timekeeper.getInstance()._findListener(this) == -1)  
    return (this.setZoomOrig(z, fixedPoint, animate));
});


// ************
// SMap.Control.Selection - modify to right click


// set more params
encapsulate(SMap.Control.Selection.prototype, "$constructor", function(thickness)
{
  // call and backup $super()
  this.$super();
  var temp = this.$super;
  this.$super = function(){};
  
  // note: Firefox and SHIFT+right click launches app context menu (can't be overridden)
  // - customStartDrag - called on mousedown
  // - customRedraw - called on mousemove 
  // - customHandler - called on draw finish (mouse up)
  // - customFailDrag - called on finish, but when mouse movement was too small and customHandler wouldn't be triggered
  var options = (typeof thickness === 'object') ? thickness : {thickness: thickness};
  this.customHandler = options.customHandler || null;
  this.fillColor = options.fillColor || null;
  this.cursor = options.cursor || null;
  this.customId = options.customId || null;
  this.shift = options.shift || false;
  this.ctrl = options.ctrl || false;
  this.alt = options.alt || false;
  this.meta = options.meta || false;
  this.mouseButton = (typeof options.mouseButton !== 'undefined') ? options.mouseButton : JAK.Browser.mouse.right;
  this._backupRedraw = this._redraw;   // enable us to call original redraw from our functions
  this._redraw = options.customRedraw || this._redraw;
  this.customStartDrag = options.customStartDrag || null;
  this.customFailDrag = options.customFailDrag || null; // called when dragging fails (no mouse movement)
  
  // call main function
  this.$constructorOrig(options.thickness);
  
  // restore $super()
  this.$super = temp;
});

// start selection only on dragging content (not any controls)
encapsulate(SMap.Control.Selection.prototype, "setOwner", function(owner)
{
  this.$super(owner);
  var elm = owner.getContent();
  this._ec.push(JAK.Events.addListener(elm, "mousedown", this, "_mousedown"));
});

// react on right click
encapsulate(SMap.Control.Selection.prototype, "_mousedown", function(e, elm)
{ 
  // handle special keys (allowing for custom handling)
  if (this.shift != !!e.shiftKey || this.ctrl != !!e.ctrlKey || this.alt != !!e.altKey || this.meta != !!e.metaKey
  || this.mouseButton != e.button)
    return;

  // Maxthon 2 fires mousedown on mouseup (on right click with SHIFT etc. pressed), prevent it
  if (this.mouseIsDown)
    return false;

  this.mouseIsDown = true;

  // Opera
  if (JAK.Browser.client == "opera")
    EventUtil.preventDefault(e);

  // custom function on start
  if (this.customStartDrag)
    this.customStartDrag(e, elm);

  // change cursor
  this.getMap().setCursor(this.cursor || "pointer");
 
  // *** prevent context menu from appearing ***
  var that = this;
  
  this.handleMouseUp = function(e, target)
  {
    if (that._point2 !== that._point1)
    {
      EventUtil.stopPropagation(e);
      EventUtil.preventDefault(e);  
    }

    if (e.type == "contextmenu")
    {
      while (that.contextMenuHandlers.length)
        EventUtil.removeHandler(that.contextMenuHandlers.pop());
    }
    
    else if (e.type == "mouseup")
    {
      while (that.mouseUpMenuHandlers.length)
        EventUtil.removeHandler(that.mouseUpMenuHandlers.pop());

      // remove handler for context menu here as well
      if (that.mouseButton != JAK.Browser.mouse.right)
      {
        while (that.contextMenuHandlers.length)
          EventUtil.removeHandler(that.contextMenuHandlers.pop());
      }
  
      // call mouseup function (only if any move happened)
      if (that.movedMouse)
        that._mouseup.call(that, e, target);
    }
  }
 
  // prevent context menu bubbling
  // IE7-8 --> guess map layer index (should be 0), IE9+ - use capture mode
  this.contextMenuHandlers = [];
  
  for (var i = 0; i < elm.childNodes.length; i++)
    this.contextMenuHandlers.push(EventUtil.addHandler(elm.childNodes[i], "contextmenu", this.handleMouseUp, false));

  this.contextMenuHandlers.push(EventUtil.addHandler(document.documentElement, "contextmenu", this.handleMouseUp, true));
  
  // prevent middle click bubbling (note: don't do this in IE7-8, would cause a bug)
  this.mouseUpMenuHandlers = [];
  this.mouseUpMenuHandlers.push(EventUtil.addHandler(document.documentElement, "mouseup", this.handleMouseUp, true));

  // *** call original function (e can't be modified, so create a new one) ***
  this._mousedownOrig({button: JAK.Browser.mouse.left, ctrlKey: 1, metaKey: 0, clientX: e.clientX, clientY: e.clientY}, elm);
  
  // change fill color (if set)
  if (this.fillColor)
    this._dom.container.style.backgroundColor = this.fillColor;
});

// mouse up
encapsulate(SMap.Control.Selection.prototype, "_mouseup", function(e, elm)
{
  EventUtil.preventDefault(e);
  EventUtil.stopPropagation(e);
  this.movedMouse = false;
  this.mouseIsDown = false;  /* Maxthon 2 fix */
  
  // restore cursor
  this.getMap().setCursor(null);

  // custom handler
  if (this.customHandler)
  {
    // get left-bottom/right-top points and direction where we started
    var direction = ((this._point1.x <= this._point2.x) ? "l" : "r") + ((this._point1.y <= this._point2.y) ? "t" : "b")
    var p1 = new SMap.Pixel(Math.min(this._point1.x, this._point2.x), Math.min(this._point1.y, this._point2.y));
    var p2 = new SMap.Pixel(Math.max(this._point1.x, this._point2.x), Math.max(this._point1.y, this._point2.y));

    // original cleanup
  	this._ecTmp.forEach(JAK.Events.removeListener, JAK.Events);
  	this._ecTmp = [];
   	this._hide();    

    // make sure something is selected
    var selectedSomething = (p1.x != p2.x && p1.y != p2.y);
    
    if (selectedSomething)
      this.customHandler(p1, p2, this.customId, direction);
    else if (this.customFailDrag)
      this.customFailDrag(p1, p2, this.customId, direction);
  }
  
  // default: zoom to selection
  else
  {
    this._mouseupOrig(e, elm);
  }
});

// handle mouse move
encapsulate(SMap.Control.Selection.prototype, "_mousemove", function(e, elm)
{
  this.movedMouse = true;
  return(this._mousemoveOrig(e, elm));
})

// stop moving map using mouse if alt or shift is pressed (to enable setting selection on any mouse/key combination)
encapsulate(SMap.Control.Mouse.prototype, "_mouseDown", function(e, elm)
{
  if (e.shiftKey || e.altKey)
    return;
    
  return(this._mouseDownOrig(e, elm));
});

//**********************
// implement project point function
// from: http://www.movable-type.co.uk/scripts/latlong.html
SMap.Coords.prototype.projectPoint = function(azimuth, distance)
{
  var latlon = this.toWGS84();

  var lat1 = latlon[1] * Math.PI / 180;
  var lon1 = latlon[0] * Math.PI / 180;
  
  var R = 6371000;
  var d = distance/R;  // d = angular distance covered on earth’s surface

  var brng = azimuth * Math.PI / 180;

  var dLat = d*Math.cos(brng);
  // nasty kludge to overcome ill-conditioned results around parallels of latitude:
  if (Math.abs(dLat) < 1e-10) dLat = 0; // dLat < 1 mm
  
  var lat2 = lat1 + dLat;
  var dPhi = Math.log(Math.tan(lat2/2+Math.PI/4)/Math.tan(lat1/2+Math.PI/4));
  var q = (isFinite(dLat/dPhi)) ? dLat/dPhi : Math.cos(lat1);  // E-W line gives dPhi=0
  var dLon = d*Math.sin(brng)/q;
  
  // check for some daft bugger going past the pole, normalise latitude if so
  if (Math.abs(lat2) > Math.PI/2) lat2 = lat2>0 ? Math.PI-lat2 : -Math.PI-lat2;
  
  lon2 = (lon1+dLon+3*Math.PI)%(2*Math.PI) - Math.PI;
 
  lat2 *= 180 / Math.PI;
  lon2 *= 180 / Math.PI;

  //log(this.distance(SMap.Coords.fromWGS84(lon2, lat2)) - distance);
  return SMap.Coords.fromWGS84(lon2, lat2);
}

// function to find out if current map is UTM33 based
SMap.prototype.isUTM33 = function()
{
  var projection = SMap.CONFIG[this.CurrentMapId].projection;
  return (!projection || projection === SMap.projUTM33) ? true : false;
}

// switches map (and updates layer switch)
SMap.prototype.switchMap = function(id)
{
  JAK.DOM.removeClass(document.querySelector(".layer-switch .active"), "active");
  this.getLayer(this.CurrentMapId).disable();
  this.CurrentMapId = id;
  this.getLayer(this.CurrentMapId).enable();
}

// fix distance calculation for far away places
encapsulate(SMap.Coords.prototype, "distance", function(target, altitude)
{
  if (!this.isValidOrig() || !target.isValidOrig())
  {
    var latlon = this.toWGS84("LatLon");
    var latlon2 = target.toWGS84("LatLon");
   
    var lat1 = latlon[0];
    var lon1 = latlon[1];
   
    var lat2 = latlon2[0];
    var lon2 = latlon2[1]; 
   
    var R = 6371; // km
    var dLat = (lat2-lat1) * Math.PI / 180;
    var dLon = (lon2-lon1) * Math.PI / 180;
    var lat1 = lat1 * Math.PI / 180;
    var lat2 = lat2 * Math.PI / 180;
    
    var a = Math.sin(dLat/2) * Math.sin(dLat/2) +
            Math.sin(dLon/2) * Math.sin(dLon/2) * Math.cos(lat1) * Math.cos(lat2); 
    var c = 2 * Math.atan2(Math.sqrt(a), Math.sqrt(1-a)); 
    var d = R * c;
  
    return d * 1000;  
  }

  // use original calculation for local places
  else
    return(this.distanceOrig(target, altitude));
});

// send redraw event also before the fact, not only after it
encapsulate(SMap.prototype, "_redraw", function(full)
{
  this._signals.makeEvent("map-redraw-before", this, {full:full});
  return(this._redrawOrig(full));
});

// this functions sometimes fails in IE7 and maybe IE8 - attempt to fix it
encapsulate(JAK.VML.prototype, "setCenterRadius", function(element, center, radius)
{
  try
  {
    return(this.setCenterRadiusOrig(element, center, radius));
  }
  catch(ex){/*log("JAK.VML setCenterRadius error");*/};
});

// global disabling/enabling of marker dragging (fixes some bugs in free draw mode)
SMap.prototype.disableMarkerDragging = function()
{
  this.markerDraggingDisabled = true;
  
  this.markerDraggingFnBackup = SMap.Marker.Feature.Draggable.prototype._dragStart;
  SMap.Marker.Feature.Draggable.prototype._dragStart = function(){};
}

SMap.prototype.enableMarkerDragging = function()
{
  if (!this.markerDraggingFnBackup)
    return;

  this.markerDraggingDisabled = false;
  SMap.Marker.Feature.Draggable.prototype._dragStart = this.markerDraggingFnBackup;
}

/****** add marker dblclick ******/
encapsulate(SMap.Layer.Marker.prototype, "_build", function()
{
  this._buildOrig();
  this._ec.push(JAK.Events.addListener(this._dom.container[SMap.LAYER_ACTIVE], "dblclick", this, "_dblclick"));
  this._ec.push(JAK.Events.addListener(this._dom.container[SMap.LAYER_MARKER], "dblclick", this, "_dblclick"));
});

SMap.Layer.Marker.prototype._dblclick = function(e, elm) 
{
 	var t = JAK.Events.getTarget(e);
 	var tops = [];
 	for (var p in this._dom.container) { tops.push(this._dom.container[p]); }
 	
 	for (var id in this._markers) {
 		var m = this._markers[id].marker;
 		var node = t;
 		var a = m.getActive();
 		do {
 			if (node == a) 
       {
 				m.dblclick(e, elm, "x");
 				return;
 			}
 			node = node.parentNode;
 		} while (tops.indexOf(node) == -1);
 	}
}

SMap.Marker.prototype.dblclick = function(e, elm)
{
  this.getMap().getSignals().makeEvent("marker-dblclick", this, {event:e});
};


//****************************************************************************
// implement ability to be able to retrieve coordinates from Tile

/* functions for converting Mercator tile to coordinates */
SMap.Tile.prototype.sinh = function(aValue)
{
 var myTerm1 = Math.pow(Math.E, aValue);
 var myTerm2 = Math.pow(Math.E, -aValue);
 
 return (myTerm1 - myTerm2)/2;
}

SMap.Tile.prototype.numTiles = function()
{
  return Math.abs(Math.pow(2, this.zoom) / (this.tileSize / 256));
}

SMap.Tile.prototype.mercatorToLat = function(mercatorY)
{
  return (Math.atan(this.sinh(mercatorY)) * 180 / Math.PI);
}

SMap.Tile.prototype.latEdges1 = function(tile)
{
  var unit = 1 / this.numTiles();
  var relY1 = this.y * unit;
  var lat1 = this.mercatorToLat(Math.PI * (1 - 2 * relY1));
  return lat1;
}
 
SMap.Tile.prototype.latEdges2 = function(tile)
{
  var unit = 1 / this.numTiles();
  var relY1 = this.y * unit;
  var relY2 = relY1 + unit;
  var lat2 = this.mercatorToLat(Math.PI * (1 - 2 * relY2));
  return lat2;
}

SMap.Tile.prototype.lonEdges1 = function()
{
  var unit = 360 / this.numTiles();
  var lon1 = -180 + this.x * unit;
  return lon1;
}

SMap.Tile.prototype.lonEdges2 = function()
{
  var unit = 360 / this.numTiles();
  var lon1 = -180 + this.x * unit;
  var lon2 = lon1 + unit;
  return lon2;
}

/* functions for converting UTM33 tile to coordinates */
SMap.Tile.prototype.zoomAdjust = function(PP)
{
  return ((PP * this.tileSize / 256) << (28 - this.zoom));
} 

/* get topLeft and bottomRight coords for both UTM33 and Mercator */
SMap.Tile.prototype.topLeftCoords = function(map)
{
  // handle UTM33
  if (map.isUTM33())
  {
    return (new SMap.Coords(this.zoomAdjust(this.x), this.zoomAdjust(this.y)));
  }
  
  // handle Mercator
  else
  {
    return (new SMap.Coords.fromWGS84(this.lonEdges1(), this.latEdges2()));
  }
}

SMap.Tile.prototype.bottomRightCoords = function(map)
{
  // handle UTM33
  if (map.isUTM33())
  {
    return (new SMap.Coords(this.zoomAdjust(this.x + 1), this.zoomAdjust(this.y + 1)));
  }
  
  // handle Mercator
  else
  {
    return (new SMap.Coords.fromWGS84(this.lonEdges2(), this.latEdges1()));
  }
}

//******************
// support contexmenu event for geometry-click

encapsulate(SMap.Layer.Geometry.prototype, "_build", function()
{
  // original
 	this._canvas = JAK.Vector.getCanvas(1, 1); /* tenhle canvas pouzijeme jen pro vyrobu prvku, ale cpeme je do rodicovskeho */
 	var group = this._canvas.group();
 	group.id = this.id+"-"+SMap.LAYER_GEOMETRY;
 
 	this._ec.push(JAK.Events.addListener(group, "click", this, "_click"));
 	this._ec.push(JAK.Events.addListener(group, "mousedown", this, "_mouseDown"));
 
 	this._dom.container[SMap.LAYER_GEOMETRY] = group;
 	this._canvas.setContent(group);

  // our
  this._ec.push(JAK.Events.addListener(group, "contextmenu", this, "_click"));
});

//**************
// attempt to improve loading speed of ZM10 tiles

SMap.Layer.Tile.prototype._buildElement = function(tile)
{
var url = this._buildURL(tile.tile);

if (JAK.Browser.client == "ie" && JAK.Browser.version < 7 && this._options.alpha) {
  	var node = this._nodes.div.cloneNode(false);
  	node.style.filter = "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='"+url+"',sizingMethod='scale')";
  } else {
  	var node = this._nodes.img.cloneNode(false);
  	node.src = url;
  	
  	if (this._currentFilter) { node.style.filter = this._currentFilter; } /* IE */
  
  	if (SMap.TRANSFORM) { /* docasne povoleno */
  		var value = "";
  		switch (this.getMap().getOrientation()) {
  			case SMap.NORTH:
  				value = "";
  			break;
  			case SMap.SOUTH:
  				value = "rotate(180deg)";
  			break;
  			case SMap.EAST:
  				value = "rotate(270deg)";
  			break;
  			case SMap.WEST:
  				value = "rotate(90deg)";
  			break;
  		}
  		node.style[SMap.TRANSFORM] = value;
  	}
  	
  }
  
  node.style.left = tile.px.x + "px";
  node.style.top = tile.px.y + "px";  
  
  if (!/cuzk/.test(url))
    return node;
  
//   // my code
//   var tmMs = 2000;
//   var that = this;
//   
//   function timeoutFn()
//   {
//     log("reload");
//     node.src = node.src;// + "&rand=" + Math.random();
//     tm = window.setTimeout(timeoutFn, tmMs);    
//   }
//   
//   var tm = window.setTimeout(timeoutFn, tmMs);
  
  node.onerror = function()
  {
    //log("error");
    node.src = node.src + "&rand=" + Math.random();
    node.onerror = null;
  };
  
  //node.onload=function(){log("load"); window.clearTimeout(tm);};
    
  // my code - ned  
  
 
  return node;
}




